@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
+/* SPDX-FileCopyrightText: 2016-2022 - Sébastien Wilmet <swilmet@gnome.org>
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
@@ -16,6 +16,8 @@
 #include <tepl/tepl-application.h>
 #include <tepl/tepl-application-window.h>
 #include <tepl/tepl-buffer.h>
+#include <tepl/tepl-encoding.h>
+#include <tepl/tepl-encoding-iconv.h>
 #include <tepl/tepl-file.h>
 #include <tepl/tepl-file-chooser.h>
 #include <tepl/tepl-file-loader.h>
@@ -30,10 +32,12 @@
 #include <tepl/tepl-language-chooser.h>
 #include <tepl/tepl-language-chooser-dialog.h>
 #include <tepl/tepl-language-chooser-widget.h>
+#include <tepl/tepl-line-column-indicator.h>
 #include <tepl/tepl-menu-shell.h>
 #include <tepl/tepl-metadata.h>
 #include <tepl/tepl-metadata-manager.h>
 #include <tepl/tepl-notebook.h>
+#include <tepl/tepl-overwrite-indicator.h>
 #include <tepl/tepl-panel.h>
 #include <tepl/tepl-pango.h>
 #include <tepl/tepl-prefs.h>
@@ -42,6 +46,9 @@
 #include <tepl/tepl-settings.h>
 #include <tepl/tepl-signal-group.h>
 #include <tepl/tepl-space-drawer-prefs.h>
+#include <tepl/tepl-stack.h>
+#include <tepl/tepl-stack-item.h>
+#include <tepl/tepl-stack-switcher-menu.h>
 #include <tepl/tepl-statusbar.h>
 #include <tepl/tepl-style-scheme-chooser-widget.h>
 #include <tepl/tepl-tab.h>
